@@ -4,18 +4,19 @@
 
 ;; Author: Joe Higton <draxil@gmail.com>
 ;; Contributors: Alex Drysdale <reissuecardboard@duck.com>
-;; Package-Version: 0.1.4
-;; Package-Revision: e6fae24f889d
+;; Package-Version: 20251029.707
+;; Package-Revision: 298186dc0030
 ;; Homepage: https://codeberg.org/draxil/starling-el
 ;; Package-Requires: ((emacs "29.1") (plz "0.7.2"))
 ;; Keywords: data, applications, banking
 
 ;;; Commentary:
-;;
+
 ;; Get info from your starling bank account in Emacs!
+
 ;; See the Readme.org, or go to https://codeberg.org/draxil/starling-el
 ;; for instructions on getting started.
-;;
+
 ;;; Licence:
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -243,6 +244,7 @@ Also make it a string, for display purposes."
  (setq tabulated-list-sort-key '("Name" . nil))
  (tabulated-list-init-header))
 
+;;;###autoload
 (defun starling-spaces ()
   "Show the current balances of your Starling Spaces."
   (interactive)
@@ -474,6 +476,7 @@ Optionally pick TXN-UUID."
   (setq tabulated-list-entries (starling-insights--table insights))
   (tabulated-list-print 1))
 
+;;;###autoload
 (defun starling-insights ()
   "Show the starling insights for the current month."
   (interactive)
@@ -508,7 +511,8 @@ Optionally pick TXN-UUID."
      (starling--transaction-field "Ref" (get-field 'reference))
      (starling--transaction-field "Time" (starling--txn-time txn))
      (starling--transaction-field
-      "Category" (get-field 'spendingCategory))
+      "Category"
+      (starling--format-category (get-field 'spendingCategory)))
      ;; FUTURE: more fields!
      )))
 
@@ -521,6 +525,7 @@ Optionally pick TXN-UUID."
     (insert value)
     (insert "\n")))
 
+;;;###autoload
 (defun starling-transactions ()
   "Show transactions, right now show the main account."
   (interactive)
